@@ -1,7 +1,7 @@
 <?php
 /*
 
- Copyright (c) 2001 - 2007 Ampache.org
+ Copyright (c) Ampache.org
  All Rights Reserved
 
  This program is free software; you can redistribute it and/or
@@ -20,10 +20,10 @@
 
 */ 
 $web_path = Config::get('web_path');
-$title = _('Albums by') . " " . $artist->full_name; 
+$title = sprintf(_('Albums by %s') ,$artist->full_name); 
 ?>
 <?php
-show_box_top(_('Albums by') . ' ' . $artist->f_name,'info-box');  
+show_box_top(sprintf(_('Albums by %s'), $artist->f_name),'info-box');  
 if (Config::get('ratings')) { 
 	echo "<div id=\"rating_" . $artist->id . "_artist\" style=\"display:inline;\">";
 	show_rating($artist->id, 'artist'); 
@@ -31,15 +31,17 @@ if (Config::get('ratings')) {
 } // end if ratings ?>
 <strong><?php echo _('Actions'); ?>:</strong>
 <div id="information_actions">
-<a href="<?php echo $web_path; ?>/artists.php?action=show_all_songs&amp;artist=<?php echo $artist->id; ?>"><?php echo _("Show All Songs By") . " " . $artist->f_name; ?></a><br />
-<?php echo Ajax::text('?action=basket&type=artist&id=' . $artist->id,_('Add All Songs By') . ' ' . $artist->f_name,'play_full_artist'); ?><br />
-<?php echo Ajax::text('?action=basket&type=artist_random&id=' . $artist->id,_('Add Random Songs By') . ' ' . $artist->f_name,'play_random_artist'); ?><br />
+<a href="<?php echo $web_path; ?>/artists.php?action=show_all_songs&amp;artist=<?php echo $artist->id; ?>"><?php printf(_("Show All Songs By %s"), $artist->f_name); ?></a><br />
+<?php echo Ajax::text('?action=basket&type=artist&id=' . $artist->id, sprintf(_('Add All Songs By %s'), $artist->f_name) ,'play_full_artist'); ?><br />
+<?php echo Ajax::text('?action=basket&type=artist_random&id=' . $artist->id, sprintf(_('Add Random Songs By %s'), $artist->f_name) ,'play_random_artist'); ?><br />
 <?php if ($GLOBALS['user']->has_access('50')) { ?>
 	<a href="<?php echo $web_path; ?>/artists.php?action=update_from_tags&amp;artist=<?php echo $artist->id; ?>"><?php echo _("Update from tags"); ?></a><br />
 <?php } ?>
 <?php if (Plugin::is_installed('OpenStrands')) { ?>
 <?php echo Ajax::text('?page=stats&action=show_recommend&type=artist&id=' . $artist->id,_('Recommend Similar'),'artist_recommend_similar'); ?>
 <?php } ?>
+        <input type="checkbox" id="show_artist_artCB" /> <?php echo _('Show Art'); ?>
+        <?php echo Ajax::observe('show_artist_artCB','click',Ajax::action('?page=browse&action=browse&key=show_art&value=1','')); ?>
 </div>
 <?php show_box_bottom(); ?>
 <div id="additional_information">
